@@ -1,6 +1,3 @@
-##
-##
-
 #
 # Implements IData for use by native Python clients to the Data Access
 # Framework.
@@ -11,10 +8,12 @@
 #    Date            Ticket#       Engineer       Description
 #    ------------    ----------    -----------    --------------------------
 #    06/03/13                      dgilling      Initial Creation.
+#    10/05/18                      mjames@ucar   Encode/decode attribute names.
 #
 #
 
 from awips.dataaccess import IData
+import six
 
 class PyData(IData):
 
@@ -25,7 +24,8 @@ class PyData(IData):
         self.__attributes = dataRecord.getAttributes()
 
     def getAttribute(self, key):
-        return self.__attributes[key]
+        value = self.__attributes[key]
+        return value
 
     def getAttributes(self):
         return list(self.__attributes.keys())
@@ -34,6 +34,10 @@ class PyData(IData):
         return self.__time
 
     def getLevel(self):
+        if six.PY2:
+            return self.__level
+        if type(self.__level) is not str:
+            return self.__level.decode('utf-8')
         return self.__level
 
     def getLocationName(self):
