@@ -1,6 +1,3 @@
-##
-##
-
 #
 # Implements IGeometryData for use by native Python clients to the Data Access
 # Framework.
@@ -16,11 +13,13 @@
 #                                                 is called for data that is not a
 #                                                 numeric Type.
 #    06/09/16        5574          mapeters       Handle 'SHORT' type in getNumber().
+#    10/05/18                      mjames@ucar    Encode/decode string, number val, and type
 #
 #
 
 from awips.dataaccess import IGeometryData
 from awips.dataaccess import PyData
+import six
 
 class PyGeometryData(IGeometryData, PyData.PyData):
 
@@ -36,18 +35,26 @@ class PyGeometryData(IGeometryData, PyData.PyData):
         return self.__geometry
 
     def getParameters(self):
-        return list(self.__dataMap.keys())
+        if six.PY2:
+            return list(self.__dataMap.keys())
+        else:
+            return [x.decode('utf-8') for x in list(self.__dataMap.keys())]
 
     def getString(self, param):
-        value = self.__dataMap[param][0]
+        if six.PY2:
+            return self.__dataMap[param][0]
+        value = self.__dataMap[param.encode('utf-8')][0]
+        if value is not None:
+            return value.decode('utf-8')
         return value
 
     def getNumber(self, param):
-        value = self.__dataMap[param][0]
         t = self.getType(param)
-        if t == 'INT' or t == 'SHORT':
-            return int(value)
-        elif t == 'LONG':
+        if six.PY2:
+            value = self.__dataMap[param][0]
+        else:
+            value = self.__dataMap[param.encode('utf-8')][0]
+        if t == 'INT' or t == 'SHORT' or t == 'LONG':
             return int(value)
         elif t == 'FLOAT':
             return float(value)
@@ -57,7 +64,17 @@ class PyGeometryData(IGeometryData, PyData.PyData):
             raise TypeError("Data for parameter " + param + " is not a numeric type.")
 
     def getUnit(self, param):
-        return self.__dataMap[param][2]
+        unit = self.__dataMap[param][2]
+        if six.PY2:
+            return unit
+        if unit is not None:
+            return unit.decode('utf-8')
+        return unit
 
     def getType(self, param):
-        return self.__dataMap[param][1]
+        if six.PY2:
+            return self.__dataMap[param][1]
+        type = self.__dataMap[param.encode('utf-8')][1]
+        if type is not None:
+            return type.decode('utf-8')
+        return type
