@@ -1,11 +1,7 @@
-##
-##
-
-from __future__ import print_function
 from awips.dataaccess import DataAccessLayer as DAL
 
-import baseBufrMosTestCase
-import params
+from awips.test.dafTests import baseBufrMosTestCase
+from awips.test.dafTests import params
 import unittest
 
 #
