@@ -1,21 +1,4 @@
 ##
-# This software was developed and / or modified by Raytheon Company,
-# pursuant to Contract DG133W-05-CQ-1067 with the US Government.
-#
-# U.S. EXPORT CONTROLLED TECHNICAL DATA
-# This software product contains export-restricted data whose
-# export/transfer/disclosure is restricted by U.S. law. Dissemination
-# to non-U.S. persons whether in the United States or abroad requires
-# an export license or other authorization.
-#
-# Contractor Name:        Raytheon Company
-# Contractor Address:     6825 Pine Street, Suite 340
-#                         Mail Stop B8
-#                         Omaha, NE 68106
-#                         402.291.0100
-#
-# See the AWIPS II Master Rights File ("Master Rights File.pdf") for
-# further licensing information.
 ##
 #
 #     SOFTWARE HISTORY
@@ -24,6 +7,7 @@
 #    ------------    ----------    -----------    --------------------------
 #    05/22/2015       4522         randerso       Initial creation
 #    03/17/2016       5426         randerso       Add issueYear to primary key
+#    08/03/2016       19213        ryu            Add pil to primary key
 #
 ##
 class ActiveTableKey(object):
@@ -35,6 +19,7 @@ class ActiveTableKey(object):
         self.etn = None
         self.ugcZone = None
         self.issueYear = None
+        self.pil = None
 
     def getOfficeid(self):
         return self.officeid
@@ -71,3 +56,9 @@ class ActiveTableKey(object):
 
     def setIssueYear(self, issueYear):
         self.issueYear = issueYear
+
+    def getPil(self):
+        return self.pil
+
+    def setPil(self, pil):
+        self.pil = pil
