@@ -17,8 +17,8 @@
 
 
 __all__ = [
-           'comm',
-           'SerializableExceptionWrapper',
-           ]
+            'comm',
+            'SerializableExceptionWrapper'
+          ]
 
 from .SerializableExceptionWrapper import SerializableExceptionWrapper
