@@ -17,7 +17,7 @@
 
 
 __all__ = [
-           'ServerErrorResponse',
-           ]
+            'ServerErrorResponse'
+          ]
 
 from .ServerErrorResponse import ServerErrorResponse
