@@ -17,7 +17,7 @@
 
 
 __all__ = [
-           'Point',
-           ]
+            'Point'
+          ]
 
 from .Point import Point
